@@ -35,7 +35,7 @@ if(d>0){
 neighbrs<-list()
 
 for(kk in 1:length(rem)){
-	neighbrs[[kk]]<-.C("nbrsfromlca",as.double(t(lca)),as.integer(ncol(lca)),as.integer(kk),
+	neighbrs[[kk]]<-.C(C_nbrsfromlca,as.double(t(lca)),as.integer(ncol(lca)),as.integer(kk),
 			n=as.integer(rep(0,times=lca[kk,2])))$n
 }
 
